Summary:	Globally/Universally Unique Identifiers (GUIDs/UUIDs)
Name:		perl-Data-UUID
Version:	1.226
Release:	5%{?dist}
License:	BSD and MIT
URL:		https://metacpan.org/release/Data-UUID
Source0:	https://cpan.metacpan.org/modules/by-module/Data/Data-UUID-%{version}.tar.gz

BuildRequires:	gcc make coreutils findutils
BuildRequires:	perl-devel perl-generators perl-interpreter
BuildRequires:	perl(Config) perl(ExtUtils::MakeMaker) perl(File::Spec)
BuildRequires:	perl(Getopt::Long) perl(Pod::Usage) perl(warnings)
BuildRequires:	perl(blib) perl(Carp) perl(Digest::MD5)
BuildRequires:	perl(DynaLoader) perl(Exporter) perl(strict)
# For test
BuildRequires:	perl(Test::More) perl(threads)

%{?perl_default_filter}

%description
This module provides a framework for generating v3 UUIDs (Universally Unique
Identifiers, also known as GUIDs (Globally Unique Identifiers). A UUID is 128
bits long, and is guaranteed to be different from all other UUIDs/GUIDs
generated until 3400 CE.

UUIDs were originally used in the Network Computing System (NCS) and later in
the Open Software Foundation's (OSF) Distributed Computing Environment.
Currently many different technologies rely on UUIDs to provide unique identity
for various software components. Microsoft COM/DCOM for instance, uses GUIDs
very extensively to uniquely identify classes, applications and components
across network-connected systems.

The algorithm for UUID generation, used by this extension, is described in the
Internet Draft "UUIDs and GUIDs" by Paul J. Leach and Rich Salz (see RFC 4122).
It provides a reasonably efficient and reliable framework for generating UUIDs
and supports fairly high allocation rates - 10 million per second per machine -
and therefore is suitable for identifying both extremely short-lived and very
persistent objects on a given system as well as across the network.

This module provides several methods to create a UUID. In all methods,
<namespace> is a UUID and <name> is a free form string.

%prep
%setup -q -n Data-UUID-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}" NO_PACKLIST=1
%make_build

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name '*.bs' -empty -delete
%{_fixperms} -c %{buildroot}


%check
make test AUTHOR_TESTING=1
perl smp-test/collision.t


%files
%license LICENSE
%doc Changes README
%{perl_vendorarch}/auto/Data/
%{perl_vendorarch}/Data/
%{_mandir}/man3/Data::UUID.3*


%changelog
* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.226-5
- Rebuilt for OpenCloudOS Stream 23.09

* Tue Aug 15 2023 Xiaojie Chen <jackxjchen@tencent.com> - 1.226-4
- Remove perl(:MODULE_COMPAT) which will be generated by perl-generators >= 1.15

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.226-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.226-2
- Rebuilt for OpenCloudOS Stream 23

* Mon Dec 12 2022 rockerzhu <rockerzhu@tencent.com> - 1.226-1
- Initial build
